==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/Infogene.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import org.sharengo.wikitty.BusinessEntity;

public interface Infogene extends BusinessEntity {

	static final public String EXT_INFOGENE = "Infogene";

    static final public String FIELD_ID = "id";
    static final public String FQ_FIELD_ID = EXT_INFOGENE + ".id";
    static final public String FIELD_OBJET = "objet";
    static final public String FQ_FIELD_OBJET = EXT_INFOGENE + ".objet";
    static final public String FIELD_CREATIONDATE = "creationDate";
    static final public String FQ_FIELD_CREATIONDATE = EXT_INFOGENE + ".creationDate";
    static final public String FIELD_SOURCEURL = "sourceURL";
    static final public String FQ_FIELD_SOURCEURL = EXT_INFOGENE + ".sourceURL";
    static final public String FIELD_SOURCETEXT = "sourceText";
    static final public String FQ_FIELD_SOURCETEXT = EXT_INFOGENE + ".sourceText";
    static final public String FIELD_ENTITY = "entity";
    static final public String FQ_FIELD_ENTITY = EXT_INFOGENE + ".entity";
    static final public String FIELD_COUNTRY = "country";
    static final public String FQ_FIELD_COUNTRY = EXT_INFOGENE + ".country";
    static final public String FIELD_DEPARTMENT = "department";
    static final public String FQ_FIELD_DEPARTMENT = EXT_INFOGENE + ".department";
    static final public String FIELD_DESCRIPTION = "description";
    static final public String FQ_FIELD_DESCRIPTION = EXT_INFOGENE + ".description";
    static final public String FIELD_STATUS = "status";
    static final public String FQ_FIELD_STATUS = EXT_INFOGENE + ".status";

    public void setId(String id);
    public String getId();


    public void setObjet(String objet);
    public String getObjet();


    public void setCreationDate(Date creationDate);
    public Date getCreationDate();


    public void setSourceURL(String sourceURL);
    public String getSourceURL();


    public void setSourceText(String sourceText);
    public String getSourceText();


    public void setEntity(String entity);
    public String getEntity();


    public void setCountry(String country);
    public String getCountry();


    public void setDepartment(String department);
    public String getDepartment();


    public void setDescription(String description);
    public String getDescription();


    public void setStatus(String status);
    public String getStatus();


} //Infogene

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/Infogene.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Infogene extends BusinessEntity {

    static final public String EXT_INFOGENE = "Infogene";

    static final public String FIELD_ID = "id";
    static final public String FQ_FIELD_ID = EXT_INFOGENE + ".id";
    static final public String FIELD_OBJET = "objet";
    static final public String FQ_FIELD_OBJET = EXT_INFOGENE + ".objet";
    static final public String FIELD_CREATIONDATE = "creationDate";
    static final public String FQ_FIELD_CREATIONDATE = EXT_INFOGENE + ".creationDate";
    static final public String FIELD_SOURCEURL = "sourceURL";
    static final public String FQ_FIELD_SOURCEURL = EXT_INFOGENE + ".sourceURL";
    static final public String FIELD_SOURCETEXT = "sourceText";
    static final public String FQ_FIELD_SOURCETEXT = EXT_INFOGENE + ".sourceText";
    static final public String FIELD_ENTITY = "entity";
    static final public String FQ_FIELD_ENTITY = EXT_INFOGENE + ".entity";
    static final public String FIELD_COUNTRY = "country";
    static final public String FQ_FIELD_COUNTRY = EXT_INFOGENE + ".country";
    static final public String FIELD_DEPARTMENT = "department";
    static final public String FQ_FIELD_DEPARTMENT = EXT_INFOGENE + ".department";
    static final public String FIELD_DESCRIPTION = "description";
    static final public String FQ_FIELD_DESCRIPTION = EXT_INFOGENE + ".description";
    static final public String FIELD_TAG = "tag";
    static final public String FQ_FIELD_TAG = EXT_INFOGENE + ".tag";
    static final public String FIELD_STATUS = "status";
    static final public String FQ_FIELD_STATUS = EXT_INFOGENE + ".status";

    public void setId(String id);
    public String getId();


    public void setObjet(String objet);
    public String getObjet();


    public void setCreationDate(Date creationDate);
    public Date getCreationDate();


    public void setSourceURL(String sourceURL);
    public String getSourceURL();


    public void setSourceText(String sourceText);
    public String getSourceText();


    public void setEntity(String entity);
    public String getEntity();


    public void setCountry(String country);
    public String getCountry();


    public void setDepartment(String department);
    public String getDepartment();


    public void setDescription(String description);
    public String getDescription();

    public Set<String> getTag();
    public void addTag(String element);
    public void removeTag(String element);
    public void clearTag();


    public void setStatus(String status);
    public String getStatus();


} //Infogene
